@@ -10,7 +10,7 @@
 
 struct extensible {
     char            name[STRMAX];
-    char            command[STRMAX];
+    char           *command;
     char            fixcmd[STRMAX];
     int             type;
     int             result;
@@ -23,10 +23,23 @@ struct extensible {
 #if defined(WIN32)
     HANDLE          tid;                /* WIN32 thread */
 #endif
+#ifdef USING_SINGLE_COMMON_PASSPERSIST_INSTANCE
+    struct extensible *passpersist_inst;
+#endif /* USING_SINGLE_COMMON_PASSPERSIST_INSTANCE */
 };
 
+#if HAVE_PCRE_H
+/* Pointer to pcre struct. Abstract pcre native pointer so all *.c files */
+/* do not have to include pcre.h */
+struct real_pcre;
+typedef struct real_pcre *netsnmp_regex_ptr;
+#endif
+
 struct myproc {
     char            name[STRMAX];
+#if HAVE_PCRE_H
+    netsnmp_regex_ptr regexp;
+#endif
     char            fixcmd[STRMAX];
     int             min;
     int             max;
